@@ -50,7 +50,7 @@ struct mlt_animation_s
 	char *data;           /**< the string representing the animation */
 	int length;           /**< the maximum number of frames to use when interpreting negative keyframe positions */
 	double fps;           /**< framerate to use when converting time clock strings to frame units */
-	locale_t locale;      /**< pointer to a locale to use when converting strings to numeric values */
+	mlt_locale_t locale;      /**< pointer to a locale to use when converting strings to numeric values */
 	animation_node nodes; /**< a linked list of keyframes (and possibly non-keyframe values) */
 };
 
@@ -181,7 +181,7 @@ static void mlt_animation_clean( mlt_animation self )
  * \return true if there was an error
  */
 
-int mlt_animation_parse(mlt_animation self, const char *data, int length, double fps, locale_t locale )
+int mlt_animation_parse(mlt_animation self, const char *data, int length, double fps, mlt_locale_t locale )
 {
 	if (!self) return 1;
 
@@ -603,6 +603,9 @@ int mlt_animation_prev_key( mlt_animation self, mlt_animation_item item, int pos
 	while ( node && node->next && position >= node->next->item.frame )
 		node = node->next;
 
+	if ( position < node->item.frame )
+		node = NULL;
+
 	if ( node )
 	{
 		item->frame = node->item.frame;
@@ -674,8 +677,11 @@ char *mlt_animation_serialize_cut_tf( mlt_animation self, int in, int out, mlt_t
 					break;
 
 				// Special case - crop at the out point
-				if ( item.frame > out )
+				if ( item.frame > out ) {
 					mlt_animation_get_item( self, &item, out );
+					// To ensure correct seeding
+					item.is_key = 1;
+				}
 			}
 			// We've handled the last keyframe
 			else
