@@ -3,7 +3,7 @@
  * \brief link service class
  * \see mlt_chain_s
  *
- * Copyright (C) 2020 Meltytech, LLC
+ * Copyright (C) 2020-2023 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -24,6 +24,7 @@
 #include "mlt_factory.h"
 #include "mlt_frame.h"
 #include "mlt_log.h"
+#include "mlt_tokeniser.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -47,6 +48,7 @@ mlt_chain_base;
 */
 
 static int producer_get_frame( mlt_producer parent, mlt_frame_ptr frame, int index );
+static int producer_probe( mlt_producer parent );
 static void relink_chain( mlt_chain self );
 static void chain_property_changed( mlt_service owner, mlt_chain self, char *name );
 static void source_property_changed( mlt_service owner, mlt_chain self, char *name );
@@ -78,6 +80,8 @@ mlt_chain mlt_chain_init( mlt_profile profile )
 			producer->close = ( mlt_destructor )mlt_chain_close;
 			producer->close_object = self;
 
+			mlt_properties_set_data( properties, "mlt_producer_probe", producer_probe, 0, NULL, NULL );
+
 			mlt_service_set_profile( MLT_CHAIN_SERVICE( self ), profile );
 
 			// Generate local space
@@ -123,6 +127,18 @@ void mlt_chain_set_source( mlt_chain self, mlt_producer source )
 		base->source = source;
 		mlt_properties_inc_ref( source_properties );
 
+		// Save the native source producer frame rate
+		base->source_profile = mlt_profile_clone(mlt_service_profile(MLT_CHAIN_SERVICE(self)));
+		mlt_frame frame = NULL;
+		mlt_service_get_frame(MLT_PRODUCER_SERVICE(source), &frame, 0);
+		mlt_frame_close(frame);
+		if (mlt_properties_get_int(source_properties, "meta.media.frame_rate_num") > 0 &&
+		    mlt_properties_get_int(source_properties, "meta.media.frame_rate_den") > 0)
+		{
+			base->source_profile->frame_rate_num = mlt_properties_get_int(source_properties, "meta.media.frame_rate_num");
+			base->source_profile->frame_rate_den = mlt_properties_get_int(source_properties, "meta.media.frame_rate_den");
+		}
+
 		// Create a list of all parameters used by the source producer so that
 		// they can be passed between the source producer and this chain.
 		base->source_parameters = mlt_properties_new();
@@ -393,6 +409,56 @@ void mlt_chain_close( mlt_chain self )
 	}
 }
 
+/** Attach normalizer links.
+ *
+ * \public \memberof mlt_chain_s
+ * \param self a chain
+ */
+
+extern void mlt_chain_attach_normalizers( mlt_chain self )
+{
+	if ( !self ) return;
+
+	if ( mlt_chain_link_count( self ) && mlt_properties_get_int( MLT_LINK_PROPERTIES( mlt_chain_link( self, 0 ) ), "_loader" ) )
+	{
+		// Chain already has normalizers
+		return;
+	}
+
+	static mlt_properties normalisers = NULL;
+
+	mlt_tokeniser tokenizer = mlt_tokeniser_init( );
+
+	// We only need to load the normalising properties once
+	if ( normalisers == NULL )
+	{
+		char temp[ PATH_MAX ];
+		snprintf( temp, PATH_MAX, "%s/chain_normalizers.ini", mlt_environment( "MLT_DATA" ) );
+		normalisers = mlt_properties_load( temp );
+		mlt_factory_register_for_clean_up( normalisers, ( mlt_destructor )mlt_properties_close );
+	}
+
+	// Apply normalisers
+	for ( int i = 0; i < mlt_properties_count( normalisers ); i ++ )
+	{
+		char *value = mlt_properties_get_value( normalisers, i );
+		mlt_tokeniser_parse_new( tokenizer, value, "," );
+		for ( int j = 0; j < mlt_tokeniser_count( tokenizer ); j ++ )
+		{
+			mlt_link link = mlt_factory_link( mlt_tokeniser_get_string( tokenizer, j ), NULL );
+			if ( link )
+			{
+				mlt_properties_set_int( MLT_LINK_PROPERTIES(link), "_loader", 1 );
+				mlt_chain_attach( self, link );
+				mlt_chain_move_link( self, mlt_chain_link_count( self ) - 1, 0 );
+				break;
+			}
+		}
+	}
+
+	mlt_tokeniser_close( tokenizer );
+}
+
 static int producer_get_frame( mlt_producer parent, mlt_frame_ptr frame, int index )
 {
 	int result = 1;
@@ -410,41 +476,66 @@ static int producer_get_frame( mlt_producer parent, mlt_frame_ptr frame, int ind
 	return result;
 }
 
+static int producer_probe( mlt_producer parent )
+{
+	if ( parent && parent->child )
+	{
+		mlt_chain self = parent->child;
+		mlt_chain_base *base = self->local;
+		if ( base && base->source )
+		{
+			return mlt_producer_probe( base->source );
+		}
+	}
+	return 1;
+}
+
 static void relink_chain( mlt_chain self )
 {
 	mlt_chain_base *base = self->local;
 	mlt_profile profile = mlt_service_profile( MLT_CHAIN_SERVICE(self) );
+	int i = 0;
+	int frc = 0;
 
 	if ( !base->source )
 	{
 		return;
 	}
 
-	if ( base->link_count == 0 )
+	for ( i = 0; i < base->link_count; i++ )
 	{
-		base->begin = base->source;
-		// If there are no links, the producer can operate in the final frame rate
-		mlt_service_set_profile( MLT_PRODUCER_SERVICE(base->source), profile );
+		if ( mlt_properties_get_int( MLT_LINK_PROPERTIES( base->links[i] ), "_frc" ) )
+		{
+			// A link will perform frame rate conversion.
+			frc = 1;
+			break;
+		}
+	}
+
+	if ( frc )
+	{
+		// Set the producer to be in native frame rate
+		mlt_service_set_profile( MLT_PRODUCER_SERVICE(base->source), base->source_profile );
 	}
 	else
 	{
-		if ( !base->source_profile )
-		{
-			// Save the native source producer profile
-			base->source_profile = mlt_profile_init(NULL);
-			mlt_profile_from_producer( base->source_profile, base->source );
-		}
+		// The producer can operate in the final frame rate.
+		mlt_service_set_profile( MLT_PRODUCER_SERVICE(base->source), profile );
+	}
 
-		// Set the producer to be in native frame rate
-		mlt_service_set_profile( MLT_PRODUCER_SERVICE(base->source), base->source_profile );
-
-		int i = 0;
+	if ( base->link_count == 0 )
+	{
+		base->begin = base->source;
+	}
+	else
+	{
 		base->begin = MLT_LINK_PRODUCER( base->links[0] );
-		for ( i = 0; i < base->link_count - 1; i++ )
+		// Connect the links in reverse order so that a link can query the profile of the next link
+		mlt_link_connect_next( base->links[base->link_count -1], base->source, profile );
+		for ( i = base->link_count - 2; i >= 0; i-- )
 		{
 			mlt_link_connect_next( base->links[i], MLT_LINK_PRODUCER( base->links[i+1] ), profile );
 		}
-		mlt_link_connect_next( base->links[base->link_count -1], base->source, profile );
 	}
 }
 
