@@ -3,7 +3,7 @@
  * \brief interface for all frame classes
  * \see mlt_frame_s
  *
- * Copyright (C) 2003-2022 Meltytech, LLC
+ * Copyright (C) 2003-2023 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -914,6 +914,8 @@ mlt_frame mlt_frame_clone( mlt_frame self, int is_deep )
 		mlt_frame_get_original_producer( self ), 0, NULL, NULL );
 	mlt_properties_set_data( new_props, "movit.convert",
 		mlt_properties_get_data( properties, "movit.convert", NULL), 0, NULL, NULL );
+	mlt_properties_set_data( new_props, "_movit cpu_convert",
+	    mlt_properties_get_data( properties, "_movit cpu_convert", NULL), 0, NULL, NULL );
 
 	if ( is_deep )
 	{
