@@ -50,8 +50,9 @@ Producer::Producer( Service &producer ) :
 	parent_( NULL )
 {
 	mlt_service_type type = producer.type( );
-	if ( type == producer_type || type == playlist_type || 
-		 type == tractor_type || type == multitrack_type )
+	if ( type == mlt_service_producer_type || type == mlt_service_playlist_type ||
+		 type == mlt_service_tractor_type || type == mlt_service_multitrack_type ||
+		 type == mlt_service_chain_type || type == mlt_service_link_type )
 	{
 		instance = ( mlt_producer )producer.get_service( );
 		inc_ref( );
@@ -263,3 +264,8 @@ void Producer::set_creation_time( int64_t creation_time )
 {
 	mlt_producer_set_creation_time( get_producer( ), creation_time );
 }
+
+bool Producer::probe( )
+{
+	return mlt_producer_probe( get_producer( ) );
+}
