@@ -1,6 +1,6 @@
 /*
  * factory.c -- the factory method interfaces
- * Copyright (C) 2003-2022 Meltytech, LLC
+ * Copyright (C) 2003-2023 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -31,6 +31,7 @@ extern mlt_filter filter_swresample_init( mlt_profile profile, char *arg );
 extern mlt_filter filter_swscale_init( mlt_profile profile, char *arg );
 extern mlt_producer producer_avformat_init( mlt_profile profile, const char *service, char *file );
 extern mlt_filter filter_avfilter_init( mlt_profile, mlt_service_type, const char*, char* );
+extern mlt_link link_swresample_init( mlt_profile profile, char *arg );
 
 // ffmpeg Header files
 #include <libavformat/avformat.h>
@@ -90,7 +91,10 @@ static void *create_service( mlt_profile profile, mlt_service_type type, const c
 #endif
 #ifdef SWRESAMPLE
 	if ( !strcmp( id, "swresample" ) )
-		return filter_swresample_init( profile, arg );
+		if ( type == mlt_service_filter_type )
+			return filter_swresample_init( profile, arg );
+		else if ( type == mlt_service_link_type )
+			return link_swresample_init( profile, arg );
 #endif
 	return NULL;
 }
@@ -442,10 +446,15 @@ MLT_REPOSITORY
 	void *iterator = NULL;
 	while ( ( f = (AVFilter*) av_filter_iterate( &iterator ) ) ) {
 		// Support filters that have one input and one output of the same type.
-		if ( avfilter_pad_count( f->inputs ) == 1 &&
-			avfilter_pad_count( f->outputs ) == 1 &&
-			avfilter_pad_get_type( f->inputs, 0 ) == avfilter_pad_get_type( f->outputs, 0 ) &&
-			!mlt_properties_get( blacklist, f->name ) )
+#if LIBAVFILTER_VERSION_INT< ((8<<16)+(3<<8)+101)
+		if (avfilter_pad_count(f->inputs) == 1 &&
+		    avfilter_pad_count(f->outputs) == 1 &&
+#else
+		if (avfilter_filter_pad_count(f, f->inputs) == 1 &&
+		    avfilter_filter_pad_count(f, f->outputs) == 1 &&
+#endif
+		    avfilter_pad_get_type(f->inputs, 0) == avfilter_pad_get_type(f->outputs, 0) &&
+		    !mlt_properties_get(blacklist, f->name))
 		{
 			char service_name[1024]="avfilter.";
 			strncat( service_name, f->name, sizeof( service_name ) - strlen( service_name ) -1 );
@@ -459,5 +468,7 @@ MLT_REPOSITORY
 #ifdef SWRESAMPLE
 	MLT_REGISTER( mlt_service_filter_type, "swresample", create_service );
 	MLT_REGISTER_METADATA( mlt_service_filter_type, "swresample", metadata, "filter_swresample.yml" );
+	MLT_REGISTER( mlt_service_link_type, "swresample", create_service );
+	MLT_REGISTER_METADATA( mlt_service_link_type, "swresample", metadata, "link_swresample.yml" );
 #endif
 }
