@@ -446,9 +446,9 @@ static void init_image_filtergraph( mlt_filter filter, mlt_image_format format,
 	if ( !strcmp( "lut3d", pdata->avfilter->name ) ) {
 #if defined(__GLIBC__) || defined(__APPLE__) || (__FreeBSD__)
 		// LUT data files use period for the decimal point regardless of LC_NUMERIC.
-		locale_t posix_locale = newlocale( LC_NUMERIC_MASK, "POSIX", NULL );
+		mlt_locale_t posix_locale = newlocale( LC_NUMERIC_MASK, "POSIX", NULL );
 		// Get the current locale and switch to POSIX local.
-		locale_t orig_locale  = uselocale( posix_locale );
+		mlt_locale_t orig_locale  = uselocale( posix_locale );
 		// Initialize the filter.
 		ret = avfilter_init_str(  pdata->avfilter_ctx, NULL );
 		// Restore the original locale.
