@@ -1,6 +1,6 @@
 /*
  * filter_swresample.c -- convert from one format/ configuration to another
- * Copyright (C) 2018 Meltytech, LLC
+ * Copyright (C) 2018-2022 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,6 +18,7 @@
  */
 
 #include "common.h"
+#include "common_swr.h"
 
 #include <framework/mlt.h>
 
@@ -26,110 +27,11 @@
 #include <libavutil/opt.h>
 #include <libavutil/samplefmt.h>
 
-typedef struct
-{
-	SwrContext* ctx;
-	uint8_t** in_buffers;
-	uint8_t** out_buffers;
-	mlt_audio_format in_format;
-	mlt_audio_format out_format;
-	int in_frequency;
-	int out_frequency;
-	int in_channels;
-	int out_channels;
-	mlt_channel_layout in_layout;
-	mlt_channel_layout out_layout;
-} private_data;
-
-static int configure_swr_context( mlt_filter filter )
-{
-	private_data* pdata = (private_data*)filter->child;
-	int error = 0;
-
-	mlt_log_info( MLT_FILTER_SERVICE(filter), "%d(%s) %s %dHz -> %d(%s) %s %dHz\n",
-				   pdata->in_channels, mlt_audio_channel_layout_name( pdata->in_layout ), mlt_audio_format_name( pdata->in_format ), pdata->in_frequency, pdata->out_channels, mlt_audio_channel_layout_name( pdata->out_layout ), mlt_audio_format_name( pdata->out_format ), pdata->out_frequency );
-
-	swr_free( &pdata->ctx );
-	pdata->ctx = swr_alloc();
-	if( !pdata->ctx )
-	{
-		mlt_log_error( MLT_FILTER_SERVICE(filter), "Cannot allocate context\n" );
-		return 1;
-	}
-
-	// Configure format, frequency and channels.
-	av_opt_set_int( pdata->ctx, "osf", mlt_to_av_sample_format( pdata->out_format ), 0 );
-	av_opt_set_int( pdata->ctx, "osr", pdata->out_frequency, 0 );
-	av_opt_set_int( pdata->ctx, "och", pdata->out_channels, 0);
-	av_opt_set_int( pdata->ctx, "isf", mlt_to_av_sample_format( pdata->in_format ), 0 );
-	av_opt_set_int( pdata->ctx, "isr", pdata->in_frequency,  0 );
-	av_opt_set_int( pdata->ctx, "ich", pdata->in_channels, 0 );
-
-	if( pdata->in_layout != mlt_channel_independent && pdata->out_layout != mlt_channel_independent )
-	{
-		// Use standard channel layout and matrix for known channel configurations.
-		av_opt_set_int( pdata->ctx, "ocl", mlt_to_av_channel_layout( pdata->out_layout ), 0 );
-		av_opt_set_int( pdata->ctx, "icl", mlt_to_av_channel_layout( pdata->in_layout ), 0 );
-	}
-	else
-	{
-		// Use a custom channel layout and matrix for independent channels.
-		// This matrix will simply map input channels to output channels in order.
-		// If input channels > output channels, channels will be dropped.
-		// If input channels < output channels, silent channels will be added.
-		int64_t custom_in_layout = 0;
-		int64_t custom_out_layout = 0;
-		double* matrix = av_mallocz_array( pdata->in_channels * pdata->out_channels, sizeof(double) );
-		int stride = pdata->in_channels;
-		int i = 0;
-
-		for( i = 0; i < pdata->in_channels; i++ )
-		{
-			custom_in_layout = (custom_in_layout << 1) | 0x01;
-		}
-		for( i = 0; i < pdata->out_channels; i++ )
-		{
-			custom_out_layout = (custom_out_layout << 1) | 0x01;
-			if( i < pdata->in_channels )
-			{
-				double* matrix_row = matrix + (stride * i);
-				matrix_row[i] = 1.0;
-			}
-		}
-		av_opt_set_int( pdata->ctx, "ocl", custom_out_layout, 0 );
-		av_opt_set_int( pdata->ctx, "icl", custom_in_layout, 0 );
-		error = swr_set_matrix( pdata->ctx, matrix, stride );
-		av_free( matrix );
-		if( error != 0 )
-		{
-			swr_free( &pdata->ctx );
-			mlt_log_error( MLT_FILTER_SERVICE(filter), "Unable to create custom matrix\n" );
-			return error;
-		}
-	}
-
-	error = swr_init( pdata->ctx );
-	if( error != 0 )
-	{
-		swr_free( &pdata->ctx );
-		mlt_log_error( MLT_FILTER_SERVICE(filter), "Cannot initialize context\n" );
-		return error;
-	}
-
-	// Allocate the channel buffer pointers
-	av_freep( &pdata->in_buffers );
-	pdata->in_buffers = av_mallocz_array( pdata->in_channels, sizeof(uint8_t*) );
-	av_freep( &pdata->out_buffers );
-	pdata->out_buffers = av_mallocz_array( pdata->out_channels, sizeof(uint8_t*) );
-
-	return error;
-}
-
 static int filter_get_audio( mlt_frame frame, void **buffer, mlt_audio_format *format, int *frequency, int *channels, int *samples )
 {
 	int requested_samples = *samples;
 	mlt_filter filter = mlt_frame_pop_audio( frame );
-	private_data* pdata = (private_data*)filter->child;
+	mlt_swr_private_data* pdata = (mlt_swr_private_data*)filter->child;
 	mlt_properties frame_properties = MLT_FRAME_PROPERTIES( frame );
 	struct mlt_audio_s in;
 	struct mlt_audio_s out;
@@ -193,7 +95,7 @@ static int filter_get_audio( mlt_frame frame, void **buffer, mlt_audio_format *f
 		pdata->in_layout = in.layout;
 		pdata->out_layout = out.layout;
 		// Reconfigure the context
-		error = configure_swr_context( filter );
+		error = mlt_configure_swr_context( MLT_FILTER_SERVICE(filter), pdata );
 	}
 
 	if( !error )
@@ -247,13 +149,11 @@ static mlt_frame filter_process( mlt_filter filter, mlt_frame frame )
 
 static void filter_close( mlt_filter filter )
 {
-	private_data* pdata = (private_data*)filter->child;
+	mlt_swr_private_data* pdata = (mlt_swr_private_data*)filter->child;
 
 	if( pdata )
 	{
-		swr_free( &pdata->ctx );
-		av_freep( &pdata->in_buffers );
-		av_freep( &pdata->out_buffers );
+		mlt_free_swr_context( pdata );
 		free( pdata );
 	}
 	filter->child = NULL;
@@ -265,7 +165,7 @@ static void filter_close( mlt_filter filter )
 mlt_filter filter_swresample_init( mlt_profile profile, char *arg )
 {
 	mlt_filter filter = mlt_filter_new();
-	private_data* pdata = (private_data*)calloc( 1, sizeof(private_data) );
+	mlt_swr_private_data* pdata = (mlt_swr_private_data*)calloc( 1, sizeof(mlt_swr_private_data) );
 
 	if( filter && pdata )
 	{
