@@ -1,6 +1,6 @@
 /*
  * filter_resize.c -- resizing filter
- * Copyright (C) 2003-2022 Meltytech, LLC
+ * Copyright (C) 2003-2023 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,6 +19,7 @@
 
 #include <framework/mlt_filter.h>
 #include <framework/mlt_frame.h>
+#include <framework/mlt_log.h>
 #include <framework/mlt_profile.h>
 
 #include <stdio.h>
@@ -149,6 +150,9 @@ static uint8_t *frame_resize_image( mlt_frame frame, int owidth, int oheight, ml
 	// If width and height are correct, don't do anything
 	if ( iwidth < owidth || iheight < oheight )
 	{
+		mlt_log_debug( NULL, "[filter_resize] %dx%d -> %dx%d (%s)\n",
+			iwidth, iheight, owidth, oheight, mlt_image_format_name( format ) );
+
 		uint8_t alpha_value = mlt_properties_get_int( properties, "resize_alpha" );
 		// Create the output image
 		uint8_t *output = mlt_pool_alloc( owidth * ( oheight + 1 ) * bpp );
@@ -215,11 +219,11 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 	if ( rescale != NULL && !strcmp( rescale, "none" ) )
 		return mlt_frame_get_image( frame, image, format, width, height, writable );
 
-	if ( mlt_properties_get_int( properties, "distort" ) == 0 )
+	if ( mlt_properties_get_int( properties, "distort" ) == 0 && profile )
 	{
-		// Normalise the input and out display aspect
-		int normalised_width = profile->width;
-		int normalised_height = profile->height;
+		// Normalize the input and out display aspect
+		int normalized_width = profile->width;
+		int normalized_height = profile->height;
 		int real_width = mlt_properties_get_int( properties, "meta.media.width" );
 		int real_height = mlt_properties_get_int( properties, "meta.media.height" );
 		if ( real_width == 0 )
@@ -229,23 +233,23 @@ static int filter_get_image( mlt_frame frame, uint8_t **image, mlt_image_format
 		double input_ar = aspect_ratio * real_width / real_height;
 		double output_ar = consumer_aspect * owidth / oheight;
 		
-// 		fprintf( stderr, "real %dx%d normalised %dx%d output %dx%d sar %f in-dar %f out-dar %f\n",
-// 		real_width, real_height, normalised_width, normalised_height, owidth, oheight, aspect_ratio, input_ar, output_ar);
+// 		fprintf( stderr, "real %dx%d normalized %dx%d output %dx%d sar %f in-dar %f out-dar %f\n",
+// 		real_width, real_height, normalized_width, normalized_height, owidth, oheight, aspect_ratio, input_ar, output_ar);
 
 		// Optimised for the input_ar > output_ar case (e.g. widescreen on standard)
-		int scaled_width = rint( ( input_ar * normalised_width ) / output_ar );
-		int scaled_height = normalised_height;
+		int scaled_width = rint( ( input_ar * normalized_width ) / output_ar );
+		int scaled_height = normalized_height;
 
 		// Now ensure that our images fit in the output frame
-		if ( scaled_width > normalised_width )
+		if ( scaled_width > normalized_width )
 		{
-			scaled_width = normalised_width;
-			scaled_height = rint( ( output_ar * normalised_height ) / input_ar );
+			scaled_width = normalized_width;
+			scaled_height = rint( ( output_ar * normalized_height ) / input_ar );
 		}
 
 		// Now calculate the actual image size that we want
-		owidth = rint( scaled_width * owidth / normalised_width );
-		oheight = rint( scaled_height * oheight / normalised_height );
+		owidth = rint( scaled_width * owidth / normalized_width );
+		oheight = rint( scaled_height * oheight / normalized_height );
 
 		// Tell frame we have conformed the aspect to the consumer
 		mlt_frame_set_aspect_ratio( frame, consumer_aspect );
