@@ -56,7 +56,7 @@ mlt_producer producer_melt_file_init( mlt_profile profile, mlt_service_type type
 	if ( result != NULL )
 	{
 		mlt_properties_set( MLT_PRODUCER_PROPERTIES( result ), "resource", file );
-		mlt_properties_set_int( MLT_PRODUCER_PROPERTIES( result ), "loader_normalised", 1);
+		mlt_properties_set_int( MLT_PRODUCER_PROPERTIES( result ), "loader_normalized", 1);
 	}
 
 	while( count -- )
@@ -442,6 +442,7 @@ mlt_producer producer_melt_init( mlt_profile profile, mlt_service_type type, con
 			}
 
 			chain = mlt_chain_init( profile );
+			mlt_chain_attach_normalizers( chain );
 			if ( chain != NULL )
 			{
 				producer = MLT_CHAIN_PRODUCER( chain );
