@@ -16,6 +16,13 @@ inline QLatin1String operator "" _l(const char* c, std::size_t sz)
     return QLatin1String(c, sz);
 }
 
+// inline QString debug_value(QCborValue v)
+// {
+//     QCborMap map;
+//     map["v"_l] = v;
+//     return QString(cbor_write_json(map, false));
+// }
+
 class LottieExporterState
 {
     static constexpr const char* version = "5.7.1";
@@ -315,6 +322,10 @@ public:
             jsbez["o"_l] = tan_out;
             return jsbez;
         }
+        else if ( v.userType() == qMetaTypeId<math::bezier::Point>() )
+        {
+            return point_to_lottie(v.value<math::bezier::Point>().pos);
+        }
         else if ( v.userType() == qMetaTypeId<QGradientStops>() )
         {
             QCborArray weird_ass_representation;
@@ -399,7 +410,8 @@ public:
         const TransformFunc& transform_values
     )
     {
-        /// @todo for position fields also add spatial bezier handles
+        bool position = prop->traits().type == model::PropertyTraits::Point;
+
         QCborMap jobj;
         if ( prop->keyframe_count() > 1 )
         {
@@ -411,10 +423,18 @@ public:
                 auto kf = prop->keyframe(i);
                 QVariant v = transform_values.to_lottie(kf->value(), kf->time());
                 QCborValue kf_value = keyframe_value_from_variant(v);
+
                 if ( i != 0 )
                 {
                     if ( old_kf )
                         jkf["e"_l] = kf_value;
+
+                    if ( position )
+                    {
+                        auto pkf = static_cast<model::Keyframe<QPointF>*>(kf);
+                        jkf["ti"_l] = point_to_lottie(pkf->point().tan_in - pkf->get());
+                    }
+
                     keyframes.push_back(jkf);
                 }
 
@@ -435,7 +455,15 @@ public:
                         jkf["i"_l] = keyframe_bezier_handle(kf->transition().after());
                     }
                 }
+
+                if ( position )
+                {
+                    auto pkf = static_cast<model::Keyframe<QPointF>*>(kf);
+                    jkf["to"_l] = point_to_lottie(pkf->point().tan_out - pkf->get());
+                }
             }
+            if ( position )
+                jkf.remove("to"_l);
             keyframes.push_back(jkf);
             jobj["k"_l] = keyframes;
         }
