@@ -507,6 +507,8 @@ private:
 
     void load_styler(model::Styler* styler, const QJsonObject& json_obj)
     {
+        load_visibility(styler, json_obj);
+
         std::set<QString> props = load_basic_setup(json_obj);
         for ( const QMetaObject* mo = styler->metaObject(); mo; mo = mo->superClass() )
             load_properties(
@@ -814,14 +816,15 @@ private:
                 return;
             }
 
-            /// @todo for position fields also add spatial bezier handles
+            bool position = prop->traits().type == model::PropertyTraits::Point;
+
             auto karr = obj["k"].toArray();
             for ( int i = 0; i < karr.size(); i++ )
             {
                 QJsonValue jkf = karr[i];
                 model::FrameTime time = jkf["t"].toDouble();
                 QJsonValue s = jkf["s"];
-                if ( version[0] < 5 && s.isUndefined() && i == karr.size() - 1 && i > 0 )
+                if ( s.isUndefined() && i == karr.size() - 1 && i > 0 )
                     s = karr[i-1].toObject()["e"];
                 if ( s.isArray() && is_scalar(prop) )
                     s = s.toArray()[0];
@@ -838,11 +841,43 @@ private:
                         keyframe_bezier_handle(jkf["i"]),
                         bool(jkf["h"].toInt())
                     });
+
+                    if ( position )
+                    {
+                        auto pkf = static_cast<model::Keyframe<QPointF>*>(kf);
+                        QPointF tan_out;
+                        compound_value_2d_raw(jkf["to"], tan_out);
+                        tan_out += pkf->get();
+
+                        QPointF tan_in;
+                        if ( i > 0 )
+                            compound_value_2d_raw(karr[i-1].toObject()["ti"], tan_in);
+                        tan_in += pkf->get();
+
+                        pkf->set_point({pkf->get(), tan_in, tan_out});
+                    }
                 }
                 else
                 {
-                    emit format->warning(QObject::tr("Cannot load keyframe at %1 for %2")
-                        .arg(time).arg(property_error_string(prop))
+                    QString value;
+                    if ( !v )
+                    {
+                        value = QObject::tr("(null)");
+                    }
+                    else
+                    {
+                        value = v->toString();
+                        if ( value == "" )
+                            value = QObject::tr("(empty)");
+                        value += " ";
+#if QT_VERSION_MAJOR >= 6
+                        value += QMetaType(v->userType()).name();
+#else
+                        value += QMetaType::typeName(v->userType());
+#endif
+                    }
+                    emit format->warning(QObject::tr("Cannot load keyframe at %1 for %2 with value %3")
+                        .arg(time).arg(property_error_string(prop)).arg(value)
                     );
                 }
             }
