@@ -13,235 +13,33 @@
 
 #include "path_parser.hpp"
 #include "detail.hpp"
+#include "io/animated_properties.hpp"
 
 namespace glaxnimate::io::svg::detail {
 
+using namespace glaxnimate::io::detail;
+
 class AnimateParser
 {
 public:
-    struct ValueVariant
+    struct AnimatedProperties : public glaxnimate::io::detail::AnimatedProperties
     {
-    public:
-        enum Type
-        {
-            Vector, Bezier, String
-        };
-
-        ValueVariant(std::vector<qreal> v = {})
-            : value_(std::move(v))
-        {}
-
-        ValueVariant(math::bezier::MultiBezier v )
-            : value_(std::move(v))
-        {}
-
-        ValueVariant(QString v )
-            : value_(std::move(v))
-        {}
-
-        Type type() const { return Type(value_.index()); }
-
-        const std::vector<qreal>& vector() const
-        {
-            return std::get<int(Type::Vector)>(value_);
-        }
-
-        const math::bezier::MultiBezier& bezier() const
-        {
-            return std::get<int(Type::Bezier)>(value_);
-        }
-
-        const QString& string() const
-        {
-            return std::get<int(Type::String)>(value_);
-        }
-
-        ValueVariant lerp(const ValueVariant& other, qreal t) const
-        {
-            if ( type() != other.type() )
-                return *this;
-
-            switch ( type() )
-            {
-                case Type::Vector:
-                    return math::lerp(vector(), other.vector(), t);
-                case Type::Bezier:
-                    if ( bezier().size() == 1 && other.bezier().size() == 1 )
-                    {
-                        math::bezier::MultiBezier mb;
-                        mb.beziers().push_back(bezier()[0].lerp(other.bezier()[0], t));
-                        return mb;
-                    }
-                    return *this;
-                case Type::String:
-                    return t < 1 ? string() : other.string();
-
-            }
-
-            return {};
-        }
-
-        bool compatible(const ValueVariant& other) const
-        {
-            if ( type() != other.type() )
-                return false;
-
-            if ( type() == Vector )
-                return vector().size() == other.vector().size();
-
-            return true;
-        }
-
-    private:
-        std::variant<std::vector<qreal>, math::bezier::MultiBezier, QString> value_;
-    };
-
-    struct PropertyKeyframe
-    {
-        model::FrameTime time;
-        ValueVariant values;
-        model::KeyframeTransition transition;
-    };
-
-    struct JoinedPropertyKeyframe
-    {
-        model::FrameTime time;
-        std::vector<ValueVariant> values;
-        model::KeyframeTransition transition;
-    };
-
-    struct AnimatedProperty
-    {
-        std::vector<PropertyKeyframe> keyframes;
-    };
-
-    struct JoinedProperty
-    {
-        std::variant<const AnimatedProperty*, const QString*, ValueVariant> prop;
-        int index = 0;
-
-        bool at_end() const
-        {
-            if ( prop.index() == 0 )
-                return index + 1 == int(std::get<0>(prop)->keyframes.size());
-            return true;
-        }
-
-        const PropertyKeyframe* keyframe(int off = 0) const
-        {
-            return &std::get<0>(prop)->keyframes[index+off];
-        }
-
-        template<int i>
-        decltype(auto) get() const noexcept { return std::get<i>(prop); }
-    };
-
-    struct AnimatedProperties
-    {
-        std::map<QString, AnimatedProperty> properties;
         QDomElement element;
 
-        bool has(const QString& name) const
+        bool prepare_joined(std::vector<JoinedProperty>& props) const override
         {
-            return properties.count(name);
-        }
-
-        std::vector<PropertyKeyframe> single(const QString& prop_name) const
-        {
-            auto it = properties.find(prop_name);
-            if ( it == properties.end() || it->second.keyframes.size() < 2 )
-                return {};
-            return it->second.keyframes;
-        }
-
-        std::vector<JoinedPropertyKeyframe> joined(const std::vector<QString>& prop_names) const
-        {
-            std::vector<JoinedProperty> props;
-            props.reserve(prop_names.size());
-            int found = 0;
-            for ( const auto& name : prop_names )
-            {
-                auto it = properties.find(name);
-                if ( it == properties.end() || it->second.keyframes.size() < 2 )
-                {
-                    props.push_back({&name});
-                }
-                else
-                {
-                    props.push_back({&it->second});
-                    found++;
-                }
-            }
-
-            if ( !found )
-                return {};
-
             for ( auto& p : props )
             {
                 if ( p.prop.index() == 1 )
                 {
                     if ( !element.hasAttribute(*p.get<1>()) )
-                        return {};
+                        return false;
                     p.prop = split_values(element.attribute(*p.get<1>()));
                 }
             }
 
-            std::vector<JoinedPropertyKeyframe> keyframes;
-
-            bool cont = true;
-            while ( cont )
-            {
-                model::FrameTime time = std::numeric_limits<model::FrameTime>::max();
-                for ( const auto& p : props )
-                {
-                    if ( p.prop.index() == 0 && p.keyframe()->time < time  )
-                        time = p.keyframe()->time;
-                }
-
-                std::vector<ValueVariant> values;
-                values.reserve(props.size());
-
-                std::vector<model::KeyframeTransition> transitions;
-                transitions.resize(found);
-                cont = false;
-                for ( auto& p : props )
-                {
-                    if ( p.prop.index() == 0 )
-                    {
-                        auto kf = p.keyframe();
-                        if ( (p.at_end() && kf->time <= time) || (p.index == 0 && kf->time > time) )
-                        {
-                            values.push_back(kf->values);
-                        }
-                        else if ( kf->time == time )
-                        {
-                            p.index++;
-                            values.push_back(kf->values);
-                            transitions.push_back(kf->transition);
-                            cont = true;
-                        }
-                        else
-                        {
-                            auto kf1 = p.keyframe(-1);
-                            qreal x = math::unlerp(kf1->time, kf->time, time);
-                            qreal t = kf1->transition.lerp_factor(x);
-                            values.push_back(kf1->values.lerp(kf->values, t));
-                            transitions.push_back(kf1->transition.split(x).first);
-                            cont = true;
-                        }
-                    }
-                    else
-                    {
-                        values.push_back(p.get<2>());
-                    }
-                }
-
-                keyframes.push_back({time, std::move(values), model::JoinAnimatables::Keyframe::mix_transitions(transitions)});
-            }
-
-            return keyframes;
+            return true;
         }
-
     };
 
     static std::vector<qreal> split_values(const QString& v)
@@ -308,6 +106,8 @@ public:
                 return PathDParser(str).parse();
             case ValueVariant::String:
                 return str;
+            case ValueVariant::Color:
+                return QColor(str);
         }
 
         return {};
