@@ -13,7 +13,7 @@ class AnimationContainer: public Object
 {
     GLAXNIMATE_OBJECT(AnimationContainer)
     GLAXNIMATE_PROPERTY(float, first_frame,  0, &AnimationContainer::on_first_frame_changed, &AnimationContainer::validate_first_frame, PropertyTraits::Visual)
-    GLAXNIMATE_PROPERTY(float, last_frame, 180, &AnimationContainer::on_last_frame_changed,  &AnimationContainer::validate_last_frame,  PropertyTraits::Visual)
+    GLAXNIMATE_PROPERTY(float, last_frame, -1, &AnimationContainer::on_last_frame_changed,  &AnimationContainer::validate_last_frame,  PropertyTraits::Visual)
     Q_PROPERTY(bool time_visible READ time_visible)
     Q_PROPERTY(float duration READ duration)
 
@@ -45,15 +45,8 @@ private slots:
     void on_last_frame_changed(float);
 
 private:
-    bool validate_first_frame(int f) const
-    {
-        return f >= 0 && f < last_frame.get();
-    }
-
-    bool validate_last_frame(int f) const
-    {
-        return f > first_frame.get();
-    }
+    bool validate_first_frame(int f) const;
+    bool validate_last_frame(int f) const;
 };
 
 } // namespace glaxnimate::model
