@@ -1,6 +1,6 @@
 /*
  * filter_movit_convert.cpp
- * Copyright (C) 2013-2022 Dan Dennedy <dan@dennedy.org>
+ * Copyright (C) 2013-2023 Dan Dennedy <dan@dennedy.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -51,7 +51,7 @@ static void yuv422_to_yuv422p( uint8_t *yuv422, uint8_t *yuv422p, int width, int
 static int convert_on_cpu( mlt_frame frame, uint8_t **image, mlt_image_format *format, mlt_image_format output_format )
 {
 	int error = 0;
-	mlt_filter cpu_csc = (mlt_filter) mlt_properties_get_data( MLT_FRAME_PROPERTIES( frame ), "cpu_csc", NULL );
+	mlt_filter cpu_csc = (mlt_filter) mlt_properties_get_data( MLT_FRAME_PROPERTIES( frame ), "_movit cpu_convert", NULL );
 	if ( cpu_csc ) {
 		int (* save_fp )( mlt_frame self, uint8_t **image, mlt_image_format *input, mlt_image_format output )
 			= frame->convert_image;
@@ -562,6 +562,7 @@ static int convert_image( mlt_frame frame, uint8_t **image, mlt_image_format *fo
 		MltInput *input = create_input( properties, *format, profile->width, profile->height, width, height );
 
 		if (!input) {
+			mlt_log_error(nullptr, "filter movit.convert: create_input failed\n");
 			return 1;
 		}
 
@@ -569,6 +570,7 @@ static int convert_image( mlt_frame frame, uint8_t **image, mlt_image_format *fo
 		uint8_t *img_copy = make_input_copy( *format, *image, width, height );
 
 		if (!img_copy) {
+			mlt_log_error(nullptr, "filter movit.convert: make_input_copy failed\n");
 			delete input;
 			return 1;
 		}
@@ -690,9 +692,9 @@ static mlt_frame process( mlt_filter filter, mlt_frame frame )
 
 	frame->convert_image = convert_image;
 
-	mlt_filter cpu_csc = (mlt_filter) mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), "cpu_csc", NULL );
+	mlt_filter cpu_csc = (mlt_filter) mlt_properties_get_data( MLT_FILTER_PROPERTIES( filter ), "cpu_convert", NULL );
 	mlt_properties_inc_ref( MLT_FILTER_PROPERTIES(cpu_csc) );
-	mlt_properties_set_data( properties, "cpu_csc", cpu_csc, 0,
+	mlt_properties_set_data( properties, "_movit cpu_convert", cpu_csc, 0,
 		(mlt_destructor) mlt_filter_close, NULL );
 
 	return frame;
@@ -728,16 +730,11 @@ mlt_filter filter_movit_convert_init( mlt_profile profile, mlt_service_type type
 	{
 		mlt_properties properties = MLT_FILTER_PROPERTIES( filter );
 		glsl->add_ref( properties );
-#ifdef _WIN32
-		// XXX avcolor_space is crashing on Windows in this context!
-		mlt_filter cpu_csc = NULL;
-#else
 		mlt_filter cpu_csc = create_filter( profile, "avcolor_space" );
-#endif
 		if ( !cpu_csc )
 			cpu_csc = create_filter( profile, "imageconvert" );
 		if ( cpu_csc )
-			mlt_properties_set_data( MLT_FILTER_PROPERTIES( filter ), "cpu_csc", cpu_csc, 0,
+			mlt_properties_set_data( MLT_FILTER_PROPERTIES( filter ), "cpu_convert", cpu_csc, 0,
 				(mlt_destructor) mlt_filter_close, NULL );
 		filter->process = process;
 	}
