@@ -1,6 +1,6 @@
 /*
  * consumer_xml.c -- a libxml2 serialiser of mlt service networks
- * Copyright (C) 2003-2020 Meltytech, LLC
+ * Copyright (C) 2003-2021 Meltytech, LLC
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -44,6 +44,8 @@ struct serialise_context_s
 	int tractor_count;
 	int filter_count;
 	int transition_count;
+	int chain_count;
+	int link_count;
 	int pass;
 	mlt_properties hide_map;
 	char *root;
@@ -72,7 +74,9 @@ typedef enum
 	xml_playlist,
 	xml_tractor,
 	xml_filter,
-	xml_transition
+	xml_transition,
+	xml_chain,
+	xml_link,
 }
 xml_type;
 
@@ -123,6 +127,12 @@ static char *xml_get_id( serialise_context context, mlt_service service, xml_typ
 					case xml_transition:
 						sprintf( temp, "transition%d", context->transition_count ++ );
 						break;
+					case xml_chain:
+						sprintf( temp, "chain%d", context->chain_count ++ );
+						break;
+					case xml_link:
+						sprintf( temp, "link%d", context->link_count ++ );
+						break;
 					case xml_existing:
 						// Never gets here
 						break;
@@ -195,9 +205,11 @@ static void serialise_properties( serialise_context context, mlt_properties prop
 	for ( i = 0; i < mlt_properties_count( properties ); i++ )
 	{
 		char *name = mlt_properties_get_name( properties, i );
-		if ( name != NULL &&
-			 name[ 0 ] != '_' &&
-			 mlt_properties_get_value( properties, i ) != NULL &&
+		if ( name == NULL || name[ 0 ] == '_' )
+		{
+			continue;
+		}
+		else if ( mlt_properties_get_value( properties, i ) != NULL &&
 			 ( !context->no_meta || strncmp( name, "meta.", 5 ) ) &&
 			 strcmp( name, "mlt" ) &&
 			 strcmp( name, "mlt_type" ) &&
@@ -244,6 +256,13 @@ static void serialise_properties( serialise_context context, mlt_properties prop
 				xmlNewProp( p, _x("name"), _x(name) );
 			}
 		}
+		else if ( mlt_properties_get_properties_at( properties, i ) != NULL )
+		{
+			mlt_properties child_properties = mlt_properties_get_properties_at( properties, i );
+			p = xmlNewChild( node, NULL, _x("properties"), NULL );
+			xmlNewProp( p, _x("name"), _x(name) );
+			serialise_properties( context, child_properties, p );
+		}
 	}
 }
 
@@ -269,6 +288,13 @@ static void serialise_store_properties( serialise_context context, mlt_propertie
 					p = xmlNewTextChild( node, NULL, _x("property"), _x(value) );
 				xmlNewProp( p, _x("name"), _x(name) );
 			}
+			else if ( mlt_properties_get_properties_at( properties, i ) != NULL )
+			{
+				mlt_properties child_properties = mlt_properties_get_properties_at( properties, i );
+				p = xmlNewChild( node, NULL, _x("properties"), NULL );
+				xmlNewProp( p, _x("name"), _x(name) );
+				serialise_properties( context, child_properties, p );
+			}
 		}
 	}
 }
@@ -525,8 +551,6 @@ static void serialise_tractor( serialise_context context, mlt_service service, x
 		xmlNewProp( child, _x("id"), _x(id) );
 		if ( mlt_properties_get( properties, "title" ) )
 			xmlNewProp( child, _x("title"), _x(mlt_properties_get( properties, "title" )) );
-		if ( mlt_properties_get( properties, "global_feed" ) )
-			xmlNewProp( child, _x("global_feed"), _x(mlt_properties_get( properties, "global_feed" )) );
 		if ( mlt_properties_get_position( properties, "in" ) >= 0 )
 			xmlNewProp( child, _x("in"), _x(mlt_properties_get_time( properties, "in", context->time_format )) );
 		if ( mlt_properties_get_position( properties, "out" ) >= 0 )
@@ -606,6 +630,74 @@ static void serialise_transition( serialise_context context, mlt_service service
 	}
 }
 
+static void serialise_link( serialise_context context, mlt_service service, xmlNode *node )
+{
+	xmlNode *child = node;
+	mlt_properties properties = MLT_SERVICE_PROPERTIES( service );
+
+	if ( context->pass == 0 )
+	{
+		// Get a new id - if already allocated, do nothing
+		char *id = xml_get_id( context, service, xml_link );
+		if ( id == NULL )
+			return;
+
+		child = xmlNewChild( node, NULL, _x("link"), NULL );
+
+		// Set the id
+		xmlNewProp( child, _x("id"), _x(id) );
+		if ( mlt_properties_get( properties, "title" ) )
+			xmlNewProp( child, _x("title"), _x(mlt_properties_get( properties, "title" )) );
+		if ( mlt_properties_get_position( properties, "in" ) )
+			xmlNewProp( child, _x("in"), _x( mlt_properties_get_time( properties, "in", context->time_format ) ) );
+		if ( mlt_properties_get_position( properties, "out" ) )
+			xmlNewProp( child, _x("out"), _x( mlt_properties_get_time( properties, "out", context->time_format ) ) );
+
+		serialise_properties( context, properties, child );
+		serialise_service_filters( context, service, child );
+	}
+}
+
+static void serialise_chain( serialise_context context, mlt_service service, xmlNode *node )
+{
+	int i = 0;
+	xmlNode *child = node;
+	mlt_properties properties = MLT_SERVICE_PROPERTIES( service );
+
+	if ( context->pass == 0 )
+	{
+		// Get a new id - if already allocated, do nothing
+		char *id = xml_get_id( context, service, xml_chain );
+		if ( id == NULL )
+			return;
+
+		child = xmlNewChild( node, NULL, _x("chain"), NULL );
+
+		// Set the id
+		xmlNewProp( child, _x("id"), _x(id) );
+		if ( mlt_properties_get( properties, "title" ) )
+			xmlNewProp( child, _x("title"), _x(mlt_properties_get( properties, "title" )) );
+		if ( mlt_properties_get_position( properties, "in" ) )
+			xmlNewProp( child, _x("in"), _x( mlt_properties_get_time( properties, "in", context->time_format ) ) );
+		if ( mlt_properties_get_position( properties, "out" ) )
+			xmlNewProp( child, _x("out"), _x( mlt_properties_get_time( properties, "out", context->time_format ) ) );
+
+		serialise_properties( context, properties, child );
+
+		// Serialize links
+		for ( i = 0; i < mlt_chain_link_count( MLT_CHAIN( service ) ); i++ )
+		{
+			mlt_link link = mlt_chain_link( MLT_CHAIN( service ), i );
+			if ( link && mlt_properties_get_int( MLT_LINK_PROPERTIES(link), "_loader" ) == 0 )
+			{
+				serialise_link( context, MLT_LINK_SERVICE(link), child );
+			}
+		}
+
+		serialise_service_filters( context, service, child );
+	}
+}
+
 static void serialise_service( serialise_context context, mlt_service service, xmlNode *node )
 {
 	// Iterate over consumer/producer connections
@@ -664,6 +756,15 @@ static void serialise_service( serialise_context context, mlt_service service, x
 				break;
 			}
 
+			// Treat it as a normal chain
+			else if ( mlt_properties_get_int( properties, "_original_type" ) == mlt_service_chain_type )
+			{
+				serialise_chain( context, service, node );
+				mlt_properties_set( properties, "mlt_type", "chain" );
+				if ( mlt_properties_get( properties, "xml" ) != NULL )
+					break;
+			}
+
 			// Treat it as a normal producer
 			else
 			{
@@ -673,6 +774,13 @@ static void serialise_service( serialise_context context, mlt_service service, x
 			}
 		}
 
+		// Tell about a chain
+		else if ( strcmp( mlt_type, "chain" ) == 0 )
+		{
+			serialise_chain( context, service, node );
+			break;
+		}
+
 		// Tell about a filter
 		else if ( strcmp( mlt_type, "filter" ) == 0 )
 		{
@@ -768,7 +876,6 @@ xmlDocPtr xml_make_doc( mlt_consumer consumer, mlt_service service )
 	// Assign a title property
 	if ( mlt_properties_get( properties, "title" ) != NULL )
 		xmlNewProp( root, _x("title"), _x(mlt_properties_get( properties, "title" )) );
-	mlt_properties_set_int( properties, "global_feed", 1 );
 
 	// Add a profile child element
 	if ( profile )
@@ -807,6 +914,7 @@ xmlDocPtr xml_make_doc( mlt_consumer consumer, mlt_service service )
 	context->hide_map = mlt_properties_new();
 
 	// Ensure producer is a framework producer
+	mlt_properties_set_int( properties, "_original_type", mlt_service_identify( service ) );
 	mlt_properties_set( MLT_SERVICE_PROPERTIES( service ), "mlt_type", "mlt_producer" );
 
 	// In pass one, we serialise the end producers and playlists,
@@ -992,7 +1100,7 @@ static void *consumer_thread( void *arg )
 				mlt_frame_get_audio( frame, (void**) &buffer, &aformat, &frequency, &channels, &samples );
 
 			// Close the frame
-			mlt_events_fire( properties, "consumer-frame-show", frame, NULL );
+			mlt_events_fire( properties, "consumer-frame-show", mlt_event_data_from_frame(frame) );
 			mlt_frame_close( frame );
 		}
 	}
